summaryrefslogtreecommitdiffstats
path: root/tdecore/kgenericfactory.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-22 20:20:05 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-22 20:20:05 -0600
commitb19ddece21e102b8e4b292037ca7578f60b128fe (patch)
tree6572ca25aba80849cdfa7578bbbc9121d23afbc3 /tdecore/kgenericfactory.h
parente729c6d549f12e27b358a1dad04ff254c033ac71 (diff)
downloadtdelibs-b19ddece21e102b8e4b292037ca7578f60b128fe.tar.gz
tdelibs-b19ddece21e102b8e4b292037ca7578f60b128fe.zip
Rename KInstance and KAboutData to avoid conflicts with KDE4
Diffstat (limited to 'tdecore/kgenericfactory.h')
-rw-r--r--tdecore/kgenericfactory.h54
1 files changed, 27 insertions, 27 deletions
diff --git a/tdecore/kgenericfactory.h b/tdecore/kgenericfactory.h
index 3faaae7bf..032c14302 100644
--- a/tdecore/kgenericfactory.h
+++ b/tdecore/kgenericfactory.h
@@ -39,7 +39,7 @@ public:
s_self = this;
m_catalogueInitialized = false;
}
- KGenericFactoryBase( const KAboutData *data )
+ KGenericFactoryBase( const TDEAboutData *data )
: m_aboutData(data)
{
s_self = this;
@@ -55,18 +55,18 @@ public:
s_self = 0;
}
- static KInstance *instance();
+ static TDEInstance *instance();
protected:
- virtual KInstance *createInstance()
+ virtual TDEInstance *createInstance()
{
if ( m_aboutData )
- return new KInstance( m_aboutData );
+ return new TDEInstance( m_aboutData );
if ( m_instanceName.isEmpty() ) {
kdWarning() << "KGenericFactory: instance requested but no instance name or about data passed to the constructor!" << endl;
return 0;
}
- return new KInstance( m_instanceName );
+ return new TDEInstance( m_instanceName );
}
virtual void setupTranslations( void )
@@ -86,16 +86,16 @@ protected:
private:
TQCString m_instanceName;
- const KAboutData *m_aboutData;
+ const TDEAboutData *m_aboutData;
bool m_catalogueInitialized;
- static KInstance *s_instance;
+ static TDEInstance *s_instance;
static KGenericFactoryBase<T> *s_self;
};
/* @internal */
template <class T>
-KInstance *KGenericFactoryBase<T>::s_instance = 0;
+TDEInstance *KGenericFactoryBase<T>::s_instance = 0;
/* @internal */
template <class T>
@@ -103,7 +103,7 @@ KGenericFactoryBase<T> *KGenericFactoryBase<T>::s_self = 0;
/* @internal */
template <class T>
-KInstance *KGenericFactoryBase<T>::instance()
+TDEInstance *KGenericFactoryBase<T>::instance()
{
if ( !s_instance && s_self )
s_instance = s_self->createInstance();
@@ -141,17 +141,17 @@ KInstance *KGenericFactoryBase<T>::instance()
* that the caller passed to KLibFactory's create method.
*
* In addition upon instantiation this template provides a central
* KInstance object for your component, accessible through the
* static instance() method. The instanceName argument of the
* KGenericFactory constructor is passed to the KInstance object.
*
* The creation of the KInstance object can be customized by inheriting
* from this template class and re-implementing the virtual createInstance
* method. For example it could look like this:
* \code
- * KInstance *MyFactory::createInstance()
+ * TDEInstance *MyFactory::createInstance()
* {
- * return new KInstance( myAboutData );
+ * return new TDEInstance( myAboutData );
* }
* \endcode
*
@@ -180,7 +180,7 @@ public:
/**
* @since 3.3
*/
- KGenericFactory( const KAboutData *data )
+ KGenericFactory( const TDEAboutData *data )
: KGenericFactoryBase<Product>( data )
{}
@@ -224,17 +224,17 @@ protected:
* that the caller passed to KLibFactory's create method.
*
* In addition upon instantiation this template provides a central
* KInstance object for your component, accessible through the
* static instance() method. The instanceName argument of the
* KGenericFactory constructor is passed to the KInstance object.
*
* The creation of the KInstance object can be customized by inheriting
* from this template class and re-implementing the virtual createInstance
* method. For example it could look like this:
* \code
- * KInstance *MyFactory::createInstance()
+ * TDEInstance *MyFactory::createInstance()
* {
- * return new KInstance( myAboutData );
+ * return new TDEInstance( myAboutData );
* }
* \endcode
*
@@ -275,7 +275,7 @@ public:
/**
* @since 3.3
*/
- KGenericFactory( const KAboutData *data )
+ KGenericFactory( const TDEAboutData *data )
: KGenericFactoryBase< KTypeList<Product, ProductListTail> >( data )
{}
@@ -319,17 +319,17 @@ protected:
* that the caller passed to KLibFactory's create method.
*
* In addition upon instantiation this template provides a central
* KInstance object for your component, accessible through the
* static instance() method. The instanceName argument of the
* KGenericFactory constructor is passed to the KInstance object.
*
* The creation of the KInstance object can be customized by inheriting
* from this template class and re-implementing the virtual createInstance
* method. For example it could look like this:
* \code
- * KInstance *MyFactory::createInstance()
+ * TDEInstance *MyFactory::createInstance()
* {
- * return new KInstance( myAboutData );
+ * return new TDEInstance( myAboutData );
* }
* \endcode
*
@@ -371,7 +371,7 @@ public:
/**
* @since 3.3
*/
- KGenericFactory( const KAboutData *data )
+ KGenericFactory( const TDEAboutData *data )
: KGenericFactoryBase< KTypeList<Product, ProductListTail> >( data )
{}
@@ -141,17 +141,17 @@ KInstance *KGenericFactoryBase<T>::instance()
*
* In addition upon instantiation this template provides a central
- * KInstance object for your component, accessible through the
+ * TDEInstance object for your component, accessible through the
* static instance() method. The instanceName argument of the
@@ -141,17 +141,17 @@ KInstance *KGenericFactoryBase<T>::instance()
* static instance() method. The instanceName argument of the
- * KGenericFactory constructor is passed to the KInstance object.
+ * KGenericFactory constructor is passed to the TDEInstance object.
*
@@ -141,17 +141,17 @@ KInstance *KGenericFactoryBase<T>::instance()
*
- * The creation of the KInstance object can be customized by inheriting
+ * The creation of the TDEInstance object can be customized by inheriting
* from this template class and re-implementing the virtual createInstance
* method. For example it could look like this:
@@ -224,17 +224,17 @@ protected:
*
* In addition upon instantiation this template provides a central
- * KInstance object for your component, accessible through the
+ * TDEInstance object for your component, accessible through the
* static instance() method. The instanceName argument of the
@@ -224,17 +224,17 @@ protected:
* static instance() method. The instanceName argument of the
- * KGenericFactory constructor is passed to the KInstance object.
+ * KGenericFactory constructor is passed to the TDEInstance object.
*
@@ -224,17 +224,17 @@ protected:
*
- * The creation of the KInstance object can be customized by inheriting
+ * The creation of the TDEInstance object can be customized by inheriting
* from this template class and re-implementing the virtual createInstance
* method. For example it could look like this:
@@ -319,17 +319,17 @@ protected:
*
* In addition upon instantiation this template provides a central
- * KInstance object for your component, accessible through the
+ * TDEInstance object for your component, accessible through the
* static instance() method. The instanceName argument of the
@@ -319,17 +319,17 @@ protected:
* static instance() method. The instanceName argument of the
- * KGenericFactory constructor is passed to the KInstance object.
+ * KGenericFactory constructor is passed to the TDEInstance object.
*
@@ -319,17 +319,17 @@ protected:
*
- * The creation of the KInstance object can be customized by inheriting
+ * The creation of the TDEInstance object can be customized by inheriting
* from this template class and re-implementing the virtual createInstance
* method. For example it could look like this: